@@ -1,26 +1,34 @@
 import os
 import tempfile
 
-from vectorcode.chunking import FileChunker, StringChunker, TreeSitterChunker
+import pytest
+
+from vectorcode.chunking import (
+    ChunkerBase,
+    FileChunker,
+    StringChunker,
+    TreeSitterChunker,
+)
+from vectorcode.cli_utils import Config
 
 
 class TestChunking:
     file_chunker = FileChunker()
 
     def test_string_chunker(self):
-        string_chunker = StringChunker(chunk_size=-1, overlap_ratio=0.5)
+        string_chunker = StringChunker(Config(chunk_size=-1, overlap_ratio=0.5))
         assert list(string_chunker.chunk("hello world")) == ["hello world"]
-        string_chunker = StringChunker(chunk_size=5, overlap_ratio=0.5)
+        string_chunker = StringChunker(Config(chunk_size=5, overlap_ratio=0.5))
         assert list(string_chunker.chunk("hello world")) == [
             "hello",
             "llo w",
             "o wor",
             "world",
         ]
-        string_chunker = StringChunker(chunk_size=5, overlap_ratio=0)
+        string_chunker = StringChunker(Config(chunk_size=5, overlap_ratio=0))
         assert list(string_chunker.chunk("hello world")) == ["hello", " worl", "d"]
 
-        string_chunker = StringChunker(chunk_size=5, overlap_ratio=0.8)
+        string_chunker = StringChunker(Config(chunk_size=5, overlap_ratio=0.8))
         assert list(string_chunker.chunk("hello world")) == [
             "hello",
             "ello ",
@@ -40,11 +48,15 @@ class TestChunking:
         chunk_size = 100
 
         with open(file_path) as fin:
-            string_chunker = StringChunker(chunk_size=chunk_size, overlap_ratio=ratio)
+            string_chunker = StringChunker(
+                Config(chunk_size=chunk_size, overlap_ratio=ratio)
+            )
             string_chunks = list(string_chunker.chunk(fin.read()))
 
         with open(file_path) as fin:
-            file_chunker = FileChunker(chunk_size=chunk_size, overlap_ratio=ratio)
+            file_chunker = FileChunker(
+                Config(chunk_size=chunk_size, overlap_ratio=ratio)
+            )
             file_chunks = list(file_chunker.chunk(fin))
 
         assert len(string_chunks) == len(file_chunks), (
@@ -54,9 +66,23 @@ class TestChunking:
             assert string_chunk == file_chunk
 
 
+def test_no_config():
+    assert StringChunker().config == Config()
+    assert FileChunker().config == Config()
+    assert TreeSitterChunker().config == Config()
+
+
+def test_chunker_base():
+    with pytest.raises(AssertionError):
+        ChunkerBase(Config(overlap_ratio=-1))
+    with pytest.raises(NotImplementedError):
+        ChunkerBase().chunk("hello")
+    assert ChunkerBase().config == Config()
+
+
 def test_treesitter_chunker_python():
     """Test TreeSitterChunker with a sample file using tempfile."""
-    chunker = TreeSitterChunker(chunk_size=30)
+    chunker = TreeSitterChunker(Config(chunk_size=30))
 
     test_content = r"""
 def foo():
@@ -75,8 +101,90 @@ def bar():
     os.remove(test_file)
 
 
+def test_treesitter_chunker_filter():
+    chunker = TreeSitterChunker(
+        Config(chunk_size=30, chunk_filters={"python": [".*foo.*"]})
+    )
+
+    test_content = r"""
+def foo():
+    return "foo"
+
+def bar():
+    return "bar"
+    """
+
+    with tempfile.NamedTemporaryFile(mode="w", delete=False, suffix=".py") as tmp_file:
+        tmp_file.write(test_content)
+        test_file = tmp_file.name
+
+    chunks = list(chunker.chunk(test_file))
+    assert chunks == ['def bar():\n    return "bar"']
+    os.remove(test_file)
+
+
+def test_treesitter_chunker_filter_merging():
+    chunker = TreeSitterChunker(
+        Config(chunk_size=30, chunk_filters={"python": [".*foo.*", ".*bar.*"]})
+    )
+
+    test_content = r"""
+def foo():
+    return "foo"
+
+def bar():
+    return "bar"
+    """
+
+    with tempfile.NamedTemporaryFile(mode="w", delete=False, suffix=".py") as tmp_file:
+        tmp_file.write(test_content)
+        test_file = tmp_file.name
+
+    chunks = list(chunker.chunk(test_file))
+    assert chunks == []
+    os.remove(test_file)
+
+
+def test_treesitter_chunker_filter_wildcard():
+    chunker = TreeSitterChunker(Config(chunk_size=30, chunk_filters={"*": [".*foo.*"]}))
+
+    test_content = r"""
+def foo():
+    return "foo"
+
+def bar():
+    return "bar"
+    """
+
+    with tempfile.NamedTemporaryFile(mode="w", delete=False, suffix=".py") as tmp_file:
+        tmp_file.write(test_content)
+        test_file = tmp_file.name
+
+    chunks = list(chunker.chunk(test_file))
+    assert chunks == ['def bar():\n    return "bar"']
+    os.remove(test_file)
+
+    test_content = r"""
+function foo()
+  return "foo"
+end
+
+function bar()
+  return "bar"
+end
+    """
+
+    with tempfile.NamedTemporaryFile(mode="w", delete=False, suffix=".lua") as tmp_file:
+        tmp_file.write(test_content)
+        test_file = tmp_file.name
+
+    chunks = list(chunker.chunk(test_file))
+    assert chunks == ['functionbar()return "bar"end']
+    os.remove(test_file)
+
+
 def test_treesitter_chunker_lua():
-    chunker = TreeSitterChunker(chunk_size=30)
+    chunker = TreeSitterChunker(Config(chunk_size=30))
     test_content = r"""
 function foo()
   return "foo"
@@ -98,7 +206,7 @@ end
 
 
 def test_treesitter_chunker_ruby():
-    chunker = TreeSitterChunker(chunk_size=30)
+    chunker = TreeSitterChunker(Config(chunk_size=30))
     test_content = r"""
 def greet_user(name)
   "Hello, #{name.capitalize}!"
@@ -120,7 +228,7 @@ end
 
 
 def test_treesitter_chunker_neg_chunksize():
-    chunker = TreeSitterChunker(chunk_size=-1)
+    chunker = TreeSitterChunker(Config(chunk_size=-1))
     test_content = r"""
 def greet_user(name)
   "Hello, #{name.capitalize}!"
@@ -146,9 +254,11 @@ def test_treesitter_chunker_fallback():
     chunk_size = 30
     overlap_ratio = 0.2
     tree_sitter_chunker = TreeSitterChunker(
-        chunk_size=chunk_size, overlap_ratio=overlap_ratio
+        Config(chunk_size=chunk_size, overlap_ratio=overlap_ratio)
+    )
+    string_chunker = StringChunker(
+        Config(chunk_size=chunk_size, overlap_ratio=overlap_ratio)
     )
-    string_chunker = StringChunker(chunk_size=chunk_size, overlap_ratio=overlap_ratio)
 
     test_content = "This is a test string."
 
